<?php

namespace App\State;

use ApiPlatform\Metadata\Operation;
use ApiPlatform\State\ProviderInterface;
use App\Repository\LandValueRepository;

class AveragePricePerMonthProvider implements ProviderInterface
{
    protected $landValueRepository;

    public function __construct(LandValueRepository $landValueRepository) {
        $this->landValueRepository = $landValueRepository;
    }

    public function provide(Operation $operation, array $uriVariables = [], array $context = []): object|array|null
    {
        ini_set('memory_limit', '1024G');
        $results = $this->landValueRepository->findByAveragePricePerMonth();
        $averages = [];
        foreach ($results as $result)
        {
            $month = $result['mutationDate']->format('m');
            $year = $result['mutationDate']->format('Y');
            if (!isset($averages[$year][$month]))
            {
                $averages[$year][$month] = [
                    'sum' => 0,
                    'count' => 0,
                ];
            }
            $averages[$year][$month]['sum'] += $result['landValue'] / $result['actualBuiltUpArea'];
            $averages[$year][$month]['count']++;
        }
        $items = [];
        foreach ($averages as $year => $months)
        {
            foreach ($months as $month => $data)
            {
                $date = new \DateTime();
                $date->setDate($year, $month, 1);
                $items[] = [
                    'mutationDate' => $date->format('m/Y'),
                    'average' => $data['sum'] / $data['count'],
                ];
            }
        }
        return $items;
    }
}
